==> artcube-2-dev-plugin-4.0.2.tgz: package/app/containers/SignUpPage/index.js <==
import React, { useState } from 'react';
import styled from 'styled-components';
import { Steps, Button, Modal, Spin } from 'antd';
import { Formik } from 'formik';
import { Form } from 'formik-antd';
import { useHistory } from 'react-router-dom';

import PeopleImage from '../../images/type-account/people.png';
import BusinessImage from '../../images/type-account/business.png';

import SetUpAccount from './SetUpAccount';
import InformationPeople from './InformationPeople';
import InformationBusiness from './InformationBusiness';
import Payment from './Payment';
import validationSchema from './Validation.Schema';
import { ModalAddUrl } from './component/ModalAddUrl';
import { formatFormByType } from './utils';

import {
  checkEmailExisted as checkMailExisted,
  checkUserName,
  signUp as signUpService,
} from '../../services/Auth';
import axios from '../../axios';

const { Step } = Steps;

export const SignUp = () => {
  const [current, setCurrent] = useState(0);
  const [typeAccount, setTypeAccount] = useState('Business');
  const [formData, setFormData] = useState({});
  const [price, setPrice] = useState(0);
  const [stripeCity, setStripeCity] = useState(null);
  const [isFishTrigger, setIsFinishTrigger] = useState(null);
  const [displayModal, setDisplayModal] = useState(false);
  const [showModalAddUrl, setShowModalAddUrl] = useState(false);
  const [valueCategory, setValueCategory] = useState([]);
  const [loading, setLoading] = useState(false);
  const history = useHistory();
  const emailValidation = new RegExp(
    '[a-zA-Z0-9]{0,}([.]?[a-zA-Z0-9]{1,})[@](gmail.com|hotmail.com|yahoo.com|outlook.com)',
  );

  const initialValues = {
    email: '',
    password: '',
    confirmPassword: '',
    companyName: '',
    firstName: '',
    lastName: '',
    title: '',
    website: '',
    categories: null,
    userName: '',
    cityStripe: '',
    address: '',
    unit: '',
    city: '',
    state: '',
    stripeToken: '',
    zipCode: '',
    phone: '',
    typeAccount: 'Business',
    termsOfService: false,
    communityGuidelines: false,
    publicSchool: false,
    nonProfit: false,
    theater: false,
    notApplicable: true,
    numberOfFullTimeEmployees: '1-2',
    profileVisibility: null,
  };

  const handleCheckEmail = async email => {
    try {
      const { data } = await checkMailExisted(email);
      if (!data) {
        throw new Error('A user with this email already exists');
      }
      next();
    } catch (e) {
      // Modal.warning({
      //   centered: true,
      //   width: 500,
      //   title: <span style={{ fontSize: 22 }}>Warning</span>,
      //   content: (
      //     <span style={{ fontSize: 18 }}>
      //       A user with this email already exists
      //     </span>
      //   ),
      // });
    }
  };

  const handleCheckUserName = async userName => {
    try {
      const { data } = await checkUserName(userName);
      if (!data) {
        throw new Error('Username is already taken');
      }
      next();
    } catch (e) {
      // Modal.warning({
      //   centered: true,
      //   width: 500,
      //   title: <span style={{ fontSize: 22 }}>Warning</span>,
      //   content: (
      //     <span style={{ fontSize: 18 }}>Username is already taken</span>
      //   ),
      // });
    }
  };

  const getAmountPlan = async (num, organization) => {
    try {
      const { data } = await axios.post('/subscription/get-plan-amount', {
        numEmployees: num,
        organization,
      });
      setPrice(data);
    } catch (e) {
      throw new Error(e);
    }
  };

  const next = () => {
    setCurrent(current + 1);
  };

  const prev = () => {
    setCurrent(current - 1);
  };

  const onSubmit = async values => {
    setFormData({ ...formData, ...values, categories: valueCategory });
    if (current < 1) return;
    const citiParse = JSON.parse(values.cityStripe);
    if (current === 2) {
      if (citiParse.name !== 'New York City') {
        setShowModalAddUrl(true);
        return;
      }
    }
    setStripeCity(citiParse);
    if (citiParse.name !== 'New York City') {
      setPrice(0);
      return;
    }
    if (typeAccount !== 'Business') {
      setPrice(5);
      return;
    }
    await getAmountPlan(values.numberOfFullTimeEmployees, {
      nonProfit: values.nonProfit,
      publicSchool: values.publicSchool,
      theater: values.theater,
    });
  };

  const applyPaymentForm = value => {
    setFormData({ ...formData, ...value });
    setShowModalAddUrl(true);
  };

  const finishTrigger = () => {
    setIsFinishTrigger(Math.random());
  };

  const showModal = () => {
    setDisplayModal(!displayModal);
  };

  const pickTypeAccount = accountType => {
    setTypeAccount(accountType);
    setDisplayModal(false);
    next();
  };
  const signUp = async value => {
    let raw = { ...formData, ...value };
    raw = formatFormByType(raw);
    try {
      setShowModalAddUrl(false);
      setLoading(true);
      await signUpService(raw);
      setLoading(false);
      // Modal.success({
      //   centered: true,
      //   width: 500,
      //   content: (
      //     <span style={{ fontSize: 18 }}>
      //       Your subscription and payment is complete.
      //     </span>
      //   ),
      //   onOk: () => {
      //     history.push('/');
      //   },
      // });
    } catch (e) {
      // Modal.warning({
      //   centered: true,
      //   width: 500,
      //   title: <span style={{ fontSize: 22 }}>Warning</span>,
      //   content: (
      //     <span style={{ fontSize: 18 }}>
      //       There was a problem completing your transaction, please try again.
      //     </span>
      //   ),
      // });
    }
  };

  const selectType = type => {
    setTypeAccount(type);
  };

  const steps = [
    {
      title: 'Set Up Your Account',
      content: <SetUpAccount onSelectType={selectType} type={typeAccount} />,
    },
    {
      title: 'Your Information',
      content:
        typeAccount === 'Business' ? (
          <InformationBusiness setValueCategory={setValueCategory} />
        ) : (
          <InformationPeople setValueCategory={setValueCategory} />
        ),
    },
    {
      title: 'Payment',
      content: (
        <Payment
          price={price}
          isFinish={isFishTrigger}
          citiStripe={stripeCity}
          onSubmitPayment={applyPaymentForm}
        />
      ),
    },
  ];

  // useEffect(() => {
  //   if (formData.stripeToken) {
  //     setShowModalAddUrl(true);
  //   }
  // }, [formData]);
  return (
    <Wrapper>
      <Container>
        <Spin spinning={loading} size="large">
          <Formik
            initialValues={initialValues}
            isValidating
            onSubmit={onSubmit}
            validationSchema={validationSchema(current, typeAccount)}
            enableReinitialize
          >
            {({ isValid, values, submitForm }) => (
              <Form labelAlign="left">
                <StepBar current={current} type="navigation">
                  {steps.map(item => (
                    <Step key={item.title} title={item.title} />
                  ))}
                </StepBar>
                <StepsContent>{steps[current].content}</StepsContent>
                <StepsAction>
                  {current < steps.length - 1 && (
                    <PrimaryNextButton
                      type="primary"
                      shape="round"
                      onClick={() => {
                        submitForm().then(() => {
                          if (isValid && current === 1) {
                            handleCheckUserName(values.userName);
                          }
                          if (isValid && current === 0) {
                            if (
                              typeAccount === 'Freelancer' &&
                              emailValidation.test(values.email)
                            ) {
                              setDisplayModal(false);
                              handleCheckEmail(values.email);
                            } else if (typeAccount === 'Business') {
                              handleCheckEmail(values.email);
                              setDisplayModal(false);
                            } else {
                              setDisplayModal(true);
                            }
                          }
                        });
                      }}
                    >
                      Next
                    </PrimaryNextButton>
                  )}
                  {current === steps.length - 1 && (
                    <Button
                      onClick={finishTrigger}
                      type="primary"
                      shape="round"
                      htmlType="submit"
                    >
                      Finish
                    </Button>
                  )}
                  {current > 0 && (
                    <Button
                      style={{ margin: '0 8px' }}
                      shape="round"
                      onClick={prev}
                    >
                      Back
                    </Button>
                  )}
                </StepsAction>
              </Form>
            )}
          </Formik>
        </Spin>
        <Modal
          onCancel={showModal}
          cancelButtonProps
          closable={false}
          visible={displayModal}
          footer={null}
          centered
          width={500}
          bodyStyle={{ padding: '50px 70px' }}
        >
          <TextTypeConfirm>
            Your email suggests that you might be a business. Please confirm
            your account type:
          </TextTypeConfirm>
          <ButtonImageGroup>
            <BoxImageStyled onClick={() => pickTypeAccount('Business')}>
              <ImageStyled src={BusinessImage} alt="business" />
            </BoxImageStyled>
            <BoxImageStyled onClick={() => pickTypeAccount('Freelancer')}>
              <ImageStyled src={PeopleImage} alt="freelancer" />
            </BoxImageStyled>
          </ButtonImageGroup>
        </Modal>
        <ModalAddUrl
          showModalAddUrl={showModalAddUrl}
          onSubmit={signUp}
          formData={formData}
        />
      </Container>
    </Wrapper>
  );
};

const Wrapper = styled.div`
  background: #1890ff;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 100%;
  min-height: 100vh;
  .ant-steps-item-finish .ant-steps-item-icon > .ant-steps-icon {
    top: -4px;
  }
`;

const Container = styled.div`
  background: white;
  width: 55vw;
  min-width: 900px;
  padding: 50px 90px;
  border-radius: 6px;
  height: 100%;
  margin: 50px;
  @media only screen and (max-width: 600px) {
    width: 100%;
    padding: 20px;
    min-width: 100%;
  }
  .ant-spin-nested-loading > div > .ant-spin {
    top: 12%;
  }
`;

const StepsContent = styled.div`
  margin-top: 16px;
  border-radius: 2px;
  text-align: center;
  padding-top: 30px;
`;

const StepsAction = styled.div`
  margin-top: 24px;
  display: flex;
  flex-direction: row-reverse;

  @media only screen and (max-width: 600px) {
    padding-bottom: 20px;
  }
`;

const ButtonImageGroup = styled.div`
  display: flex;
  flex-direction: row;
  justify-content: space-around;
  margin: 20px;
`;

const BoxImageStyled = styled.div`
  width: 120px;
  height: 120px;
  margin: 0 20px;
  display: flex;
  align-items: center;
  justify-content: center;
  cursor: pointer;
`;

const ImageStyled = styled.img`
  width: 100px;
  height: auto;
`;

const TextTypeConfirm = styled.span`
  font-size: 19px;
  font-weight: 400;
`;

const PrimaryNextButton = styled(Button)`
  font-weight: bold;
  background: #002aeb;
`;

const StepBar = styled(Steps)`
  margin-bottom: 60px;
  box-shadow: 0px -1px 0 0 #e8e8e8 inset;
  .ant-steps-item-title {
    text-transform: uppercase;
    font-weight: bold;
    display: flex;
    align-items: center;
    justify-content: center;
    position: relative;
    cursor: pointer;
    font-size: 16px;
    font-family: Roboto, sans-serif;
  }
  .ant-steps-icon {
    font-size: 15px;
    border-radius: 50%;
    width: 35px;
    height: 35px;
    display: flex;
    align-items: center;
    justify-content: center;
    margin-right: 9px;
    position: relative;
    &:after {
      content: "";
      position: absolute;
      top: 5px;
      left: 5px;
      border: solid 2px #fff;
      padding: 11px;
      display: inline-block;
      border-radius: 50%;
    }
  }
  .ant-steps-item-active {
    .ant-steps-item-title {
      color: #002aeb !important;
    }
    .ant-steps-item-icon {
      background: #fff;
      border: none;
      .ant-steps-icon {
        background: #002aeb;
        color: #fff;
      }
    }
  }
  .ant-steps-item-wait
    background: #eaeaea !important;
    .ant-steps-item-title {
      color: #00A4EF !important;
    }
    .ant-steps-item-icon {
      background: #fff;
      border: none;
      .ant-steps-icon {
        background: #00A4EF;
        color: #fff;
      }
    }
  }
  .ant-steps-item::after {
    display: none;
  }
`;

==> artcube-2-dev-plugin-4.0.3.tgz: package/app/containers/SignUpPage/index.js <==
import React, { useState } from 'react';
import styled from 'styled-components';
import { Steps, Button, Modal, Spin } from 'antd';
import { Formik } from 'formik';
import { Form } from 'formik-antd';
import { useHistory } from 'react-router-dom';

import PeopleImage from '../../images/type-account/people.png';
import BusinessImage from '../../images/type-account/business.png';

import SetUpAccount from './SetUpAccount';
import InformationPeople from './InformationPeople';
import InformationBusiness from './InformationBusiness';
import Payment from './Payment';
import validationSchema from './Validation.Schema';
import { ModalAddUrl } from './component/ModalAddUrl';
import { formatFormByType } from './utils';

import {
  checkEmailExisted as checkMailExisted,
  checkUserName,
  signUp as signUpService,
} from '../../services/Auth';
import axios from '../../axios';

const { Step } = Steps;

export const SignUp = () => {
  const [current, setCurrent] = useState(0);
  const [typeAccount, setTypeAccount] = useState('Business');
  const [formData, setFormData] = useState({});
  const [price, setPrice] = useState(0);
  const [stripeCity, setStripeCity] = useState(null);
  const [isFishTrigger, setIsFinishTrigger] = useState(null);
  const [displayModal, setDisplayModal] = useState(false);
  const [showModalAddUrl, setShowModalAddUrl] = useState(false);
  const [valueCategory, setValueCategory] = useState([]);
  const [loading, setLoading] = useState(false);
  const history = useHistory();
  const emailValidation = new RegExp(
    '[a-zA-Z0-9]{0,}([.]?[a-zA-Z0-9]{1,})[@](gmail.com|hotmail.com|yahoo.com|outlook.com)',
  );

  const initialValues = {
    email: '',
    password: '',
    confirmPassword: '',
    companyName: '',
    firstName: '',
    lastName: '',
    title: '',
    website: '',
    categories: null,
    userName: '',
    cityStripe: '',
    address: '',
    unit: '',
    city: '',
    state: '',
    stripeToken: '',
    zipCode: '',
    phone: '',
    typeAccount: 'Business',
    termsOfService: false,
    communityGuidelines: false,
    publicSchool: false,
    nonProfit: false,
    theater: false,
    notApplicable: true,
    numberOfFullTimeEmployees: '1-2',
    profileVisibility: null,
  };

  const handleCheckEmail = async email => {
    try {
      const { data } = await checkMailExisted(email);
      if (!data) {
        throw new Error('A user with this email already exists');
      }
      next();
    } catch (e) {
      Modal.warning({
        centered: true,
        width: 500,
        title: <span style={{ fontSize: 22 }}>Warning</span>,
        content: (
          <span style={{ fontSize: 18 }}>
            A user with this email already exists
          </span>
        ),
      });
    }
  };

  const handleCheckUserName = async userName => {
    try {
      const { data } = await checkUserName(userName);
      if (!data) {
        throw new Error('Username is already taken');
      }
      next();
    } catch (e) {
      Modal.warning({
        centered: true,
        width: 500,
        title: <span style={{ fontSize: 22 }}>Warning</span>,
        content: (
          <span style={{ fontSize: 18 }}>Username is already taken</span>
        ),
      });
    }
  };

  const getAmountPlan = async (num, organization) => {
    try {
      const { data } = await axios.post('/subscription/get-plan-amount', {
        numEmployees: num,
        organization,
      });
      setPrice(data);
    } catch (e) {
      throw new Error(e);
    }
  };

  const next = () => {
    setCurrent(current + 1);
  };

  const prev = () => {
    setCurrent(current - 1);
  };

  const onSubmit = async values => {
    setFormData({ ...formData, ...values, categories: valueCategory });
    if (current < 1) return;
    const citiParse = JSON.parse(values.cityStripe);
    if (current === 2) {
      if (citiParse.name !== 'New York City') {
        setShowModalAddUrl(true);
        return;
      }
    }
    setStripeCity(citiParse);
    if (citiParse.name !== 'New York City') {
      setPrice(0);
      return;
    }
    if (typeAccount !== 'Business') {
      setPrice(5);
      return;
    }
    await getAmountPlan(values.numberOfFullTimeEmployees, {
      nonProfit: values.nonProfit,
      publicSchool: values.publicSchool,
      theater: values.theater,
    });
  };

  const applyPaymentForm = value => {
    setFormData({ ...formData, ...value });
    setShowModalAddUrl(true);
  };

  const finishTrigger = () => {
    setIsFinishTrigger(Math.random());
  };

  const showModal = () => {
    setDisplayModal(!displayModal);
  };

  const pickTypeAccount = accountType => {
    setTypeAccount(accountType);
    setDisplayModal(false);
    next();
  };
  const signUp = async value => {
    let raw = { ...formData, ...value };
    raw = formatFormByType(raw);
    try {
      setShowModalAddUrl(false);
      setLoading(true);
      await signUpService(raw);
      setLoading(false);
      Modal.success({
        centered: true,
        width: 500,
        content: (
          <span style={{ fontSize: 18 }}>
            Your subscription and payment is complete.
          </span>
        ),
        onOk: () => {
          history.push('/');
        },
      });
    } catch (e) {
      Modal.warning({
        centered: true,
        width: 500,
        title: <span style={{ fontSize: 22 }}>Warning</span>,
        content: (
          <span style={{ fontSize: 18 }}>
            There was a problem completing your transaction, please try again.
          </span>
        ),
      });
    }
  };

  const selectType = type => {
    setTypeAccount(type);
  };

  const steps = [
    {
      title: 'Set Up Your Account',
      content: <SetUpAccount onSelectType={selectType} type={typeAccount} />,
    },
    {
      title: 'Your Information',
      content:
        typeAccount === 'Business' ? (
          <InformationBusiness setValueCategory={setValueCategory} />
        ) : (
          <InformationPeople setValueCategory={setValueCategory} />
        ),
    },
    {
      title: 'Payment',
      content: (
        <Payment
          price={price}
          isFinish={isFishTrigger}
          citiStripe={stripeCity}
          onSubmitPayment={applyPaymentForm}
        />
      ),
    },
  ];

  // useEffect(() => {
  //   if (formData.stripeToken) {
  //     setShowModalAddUrl(true);
  //   }
  // }, [formData]);
  return (
    <Wrapper>
      <Container>
        <Spin spinning={loading} size="large">
          <Formik
            initialValues={initialValues}
            isValidating
            onSubmit={onSubmit}
            validationSchema={validationSchema(current, typeAccount)}
            enableReinitialize
          >
            {({ isValid, values, submitForm }) => (
              <Form labelAlign="left">
                <StepBar current={current} type="navigation">
                  {steps.map(item => (
                    <Step key={item.title} title={item.title} />
                  ))}
                </StepBar>
                <StepsContent>{steps[current].content}</StepsContent>
                <StepsAction>
                  {current < steps.length - 1 && (
                    <PrimaryNextButton
                      type="primary"
                      shape="round"
                      onClick={() => {
                        submitForm().then(() => {
                          if (isValid && current === 1) {
                            handleCheckUserName(values.userName);
                          }
                          if (isValid && current === 0) {
                            if (
                              typeAccount === 'Freelancer' &&
                              emailValidation.test(values.email)
                            ) {
                              setDisplayModal(false);
                              handleCheckEmail(values.email);
                            } else if (typeAccount === 'Business') {
                              handleCheckEmail(values.email);
                              setDisplayModal(false);
                            } else {
                              setDisplayModal(true);
                            }
                          }
                        });
                      }}
                    >
                      Next
                    </PrimaryNextButton>
                  )}
                  {current === steps.length - 1 && (
                    <Button
                      onClick={finishTrigger}
                      type="primary"
                      shape="round"
                      htmlType="submit"
                    >
                      Finish
                    </Button>
                  )}
                  {current > 0 && (
                    <Button
                      style={{ margin: '0 8px' }}
                      shape="round"
                      onClick={prev}
                    >
                      Back
                    </Button>
                  )}
                </StepsAction>
              </Form>
            )}
          </Formik>
        </Spin>
        <Modal
          onCancel={showModal}
          cancelButtonProps
          closable={false}
          visible={displayModal}
          footer={null}
          centered
          width={500}
          bodyStyle={{ padding: '50px 70px' }}
        >
          <TextTypeConfirm>
            Your email suggests that you might be a business. Please confirm
            your account type:
          </TextTypeConfirm>
          <ButtonImageGroup>
            <BoxImageStyled onClick={() => pickTypeAccount('Business')}>
              <ImageStyled src={BusinessImage} alt="business" />
            </BoxImageStyled>
            <BoxImageStyled onClick={() => pickTypeAccount('Freelancer')}>
              <ImageStyled src={PeopleImage} alt="freelancer" />
            </BoxImageStyled>
          </ButtonImageGroup>
        </Modal>
        <ModalAddUrl
          showModalAddUrl={showModalAddUrl}
          onSubmit={signUp}
          formData={formData}
        />
      </Container>
    </Wrapper>
  );
}

const Wrapper = styled.div`
  background: #1890ff;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 100%;
  min-height: 100vh;
  .ant-steps-item-finish .ant-steps-item-icon > .ant-steps-icon {
    top: -4px;
  }
`;

const Container = styled.div`
  background: white;
  width: 55vw;
  min-width: 900px;
  padding: 50px 90px;
  border-radius: 6px;
  height: 100%;
  margin: 50px;
  @media only screen and (max-width: 600px) {
    width: 100%;
    padding: 20px;
    min-width: 100%;
  }
  .ant-spin-nested-loading > div > .ant-spin {
    top: 12%;
  }
`;

const StepsContent = styled.div`
  margin-top: 16px;
  border-radius: 2px;
  text-align: center;
  padding-top: 30px;
`;

const StepsAction = styled.div`
  margin-top: 24px;
  display: flex;
  flex-direction: row-reverse;

  @media only screen and (max-width: 600px) {
    padding-bottom: 20px;
  }
`;

const ButtonImageGroup = styled.div`
  display: flex;
  flex-direction: row;
  justify-content: space-around;
  margin: 20px;
`;

const BoxImageStyled = styled.div`
  width: 120px;
  height: 120px;
  margin: 0 20px;
  display: flex;
  align-items: center;
  justify-content: center;
  cursor: pointer;
`;

const ImageStyled = styled.img`
  width: 100px;
  height: auto;
`;

const TextTypeConfirm = styled.span`
  font-size: 19px;
  font-weight: 400;
`;

const PrimaryNextButton = styled(Button)`
  font-weight: bold;
  background: #002aeb;
`;

const StepBar = styled(Steps)`
  margin-bottom: 60px;
  box-shadow: 0px -1px 0 0 #e8e8e8 inset;
  .ant-steps-item-title {
    text-transform: uppercase;
    font-weight: bold;
    display: flex;
    align-items: center;
    justify-content: center;
    position: relative;
    cursor: pointer;
    font-size: 16px;
    font-family: Roboto, sans-serif;
  }
  .ant-steps-icon {
    font-size: 15px;
    border-radius: 50%;
    width: 35px;
    height: 35px;
    display: flex;
    align-items: center;
    justify-content: center;
    margin-right: 9px;
    position: relative;
    &:after {
      content: "";
      position: absolute;
      top: 5px;
      left: 5px;
      border: solid 2px #fff;
      padding: 11px;
      display: inline-block;
      border-radius: 50%;
    }
  }
  .ant-steps-item-active {
    .ant-steps-item-title {
      color: #002aeb !important;
    }
    .ant-steps-item-icon {
      background: #fff;
      border: none;
      .ant-steps-icon {
        background: #002aeb;
        color: #fff;
      }
    }
  }
  .ant-steps-item-wait
    background: #eaeaea !important;
    .ant-steps-item-title {
      color: #00A4EF !important;
    }
    .ant-steps-item-icon {
      background: #fff;
      border: none;
      .ant-steps-icon {
        background: #00A4EF;
        color: #fff;
      }
    }
  }
  .ant-steps-item::after {
    display: none;
  }
`;
